==> system-keyboard-qt_21.10.13.tar.xz: system-keyboard-qt/translations/system-keyboard-qt_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Wähle Tastatur-Layout und Variante</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Varianten</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Keine Variante</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="window.ui" line="14"/>
        <location filename="window.cpp" line="113"/>
        <location filename="window.cpp" line="117"/>
        <source>System Keyboard</source>
        <translation>Systemtastatur</translation>
    </message>
    <message>
        <location filename="window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location filename="window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Tastaturmodell</translation>
    </message>
    <message>
        <location filename="window.ui" line="55"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="window.ui" line="68"/>
        <source>Keyboard Layouts</source>
        <translation>Tastaturlayouts</translation>
    </message>
    <message>
        <location filename="window.ui" line="158"/>
        <source>Hotkeys</source>
        <translation>Tastenkombinationen</translation>
    </message>
    <message>
        <location filename="window.ui" line="181"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <location filename="window.ui" line="209"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Failed to open file: </source>
        <translation>Konnte Datei nicht öffnen:</translation>
    </message>
    <message>
        <location filename="window.cpp" line="241"/>
        <source>Most settings will not be loaded</source>
        <translation>Die meisten Einstellungen werden nicht geladen</translation>
    </message>
    <message>
        <location filename="window.cpp" line="352"/>
        <source>Disabled</source>
        <translation>deaktiviert</translation>
    </message>
</context>
</TS>

==> system-keyboard-qt_2023.04.12.tar.xz: system-keyboard-qt/translations/system-keyboard-qt_de.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>SelectLayoutDialog</name>
    <message>
        <location filename="selectlayoutdialog.ui" line="14"/>
        <source>Select Keyboard Layout and Variant</source>
        <translation>Wähle Tastatur-Layout und Variante</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="29"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.ui" line="47"/>
        <source>Variants</source>
        <translation>Varianten</translation>
    </message>
    <message>
        <location filename="selectlayoutdialog.cpp" line="57"/>
        <source>No Variant</source>
        <translation>Keine Variante</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="window.ui" line="14"/>
        <location filename="window.cpp" line="113"/>
        <location filename="window.cpp" line="117"/>
        <source>System Keyboard</source>
        <translation>Systemtastatur</translation>
    </message>
    <message>
        <location filename="window.ui" line="28"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location filename="window.ui" line="34"/>
        <source>Keyboard Model</source>
        <translation>Tastaturmodell</translation>
    </message>
    <message>
        <location filename="window.ui" line="55"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="window.ui" line="68"/>
        <source>Keyboard Layouts</source>
        <translation>Tastaturlayouts</translation>
    </message>
    <message>
        <location filename="window.ui" line="158"/>
        <source>Hotkeys</source>
        <translation>Tastenkombinationen</translation>
    </message>
    <message>
        <location filename="window.ui" line="181"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <location filename="window.ui" line="209"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="window.cpp" line="186"/>
        <location filename="window.cpp" line="204"/>
        <location filename="window.cpp" line="241"/>
        <source>Failed to open file: </source>
        <translation>Konnte Datei nicht öffnen:</translation>
    </message>
    <message>
        <location filename="window.cpp" line="241"/>
        <source>Most settings will not be loaded</source>
        <translation>Die meisten Einstellungen werden nicht geladen</translation>
    </message>
    <message>
        <location filename="window.cpp" line="352"/>
        <source>Disabled</source>
        <translation>deaktiviert</translation>
    </message>
</context>
</TS>
